Struct git_transport::client::Capabilities [−][src]
pub struct Capabilities { /* fields omitted */ }A structure to represent multiple capabilities or features supported by the server.
Implementations
impl Capabilities[src]
impl Capabilities[src]pub fn from_bytes(bytes: &[u8]) -> Result<(Capabilities, usize), Error>[src]
pub fn from_bytes(bytes: &[u8]) -> Result<(Capabilities, usize), Error>[src]Parse capabilities from the given bytes.
Useful in case they are encoded within a ref behind a null byte.
pub fn from_lines(read: impl BufRead) -> Result<Capabilities, Error>[src]
pub fn from_lines(read: impl BufRead) -> Result<Capabilities, Error>[src]Parse capabilities from the given read.
Useful for parsing capabilities from a data sent from a server.
pub fn contains(&self, feature: &str) -> bool[src]
pub fn contains(&self, feature: &str) -> bool[src]Returns true of the given feature is mentioned in this list of capabilities.
pub fn capability(&self, name: &str) -> Option<Capability<'_>>[src]
pub fn capability(&self, name: &str) -> Option<Capability<'_>>[src]Returns the capability with name.
pub fn iter(&self) -> impl Iterator<Item = Capability<'_>>[src]
pub fn iter(&self) -> impl Iterator<Item = Capability<'_>>[src]Returns an iterator over all capabilities.